@@ -4,7 +4,7 @@
 # @Software: PyCharm
 
 
-class MySDK():
+class MyTMSDK():
     def __init__(self):
         pass
 
@@ -13,5 +13,5 @@ class MySDK():
 
 
 if __name__ == '__main__':
-    runapp = MySDK()
+    runapp = MyTMSDK()
     runapp.getsome()
